@@ -16,7 +16,7 @@ T_Event = TypeVar("T_Event", bound=Dispatchable)
 
 
 class DispatcherInterface(Generic[T_Event]):
-    __slots__ = {"ctx", "broadcast", "dispatchers", "parameter_contexts", "local_storage", "current_path", "current_oplog"}
+    __slots__ = {"broadcast", "dispatchers", "parameter_contexts", "local_storage", "current_path", "current_oplog"}
 
     ctx: "ClassVar[Ctx[DispatcherInterface]]" = Ctx("bcc_dii")
 
@@ -52,18 +52,10 @@ class DispatcherInterface(Generic[T_Event]):
     def event(self) -> T_Event:
         return self.broadcast.event_ctx.get()  # type: ignore
 
-    @property
-    def global_dispatcher(self) -> List[T_Dispatcher]:
-        return self.broadcast.global_dispatchers
-
     def inject_execution_raw(self, *dispatchers: T_Dispatcher):
         for dispatcher in dispatchers:
             self.dispatchers.insert(0, dispatcher)
 
-    def inject_global_raw(self, *dispatchers: T_Dispatcher):
-        for dispatcher in dispatchers[::-1]:
-            self.broadcast.global_dispatchers.insert(1, dispatcher)
-
     async def lookup_param(
         self,
         name: str,
@@ -83,7 +75,7 @@ class DispatcherInterface(Generic[T_Event]):
                     if result.__class__ is Force:
                         return result.target
                     return result
-            oplog.clear()
+                oplog.clear()
             self.current_path.iterable = self.dispatchers
             for dispatcher in self.current_path:
                 result = await dispatcher.catch(self)
@@ -94,7 +86,7 @@ class DispatcherInterface(Generic[T_Event]):
                 if result.__class__ is Force:
                     return result.target
 
-                oplog.append(dispatcher)
+                oplog.insert(0, dispatcher)
                 return result
             else:
                 raise RequirementCrashed(
